<Query Kind="Statements">
  <Namespace>System.Runtime.InteropServices</Namespace>
</Query>

Watch (GetTestDirectory(), "*.txt", true);

void Watch (string path, string filter, bool includeSubDirs)
{
	using (var watcher = new FileSystemWatcher (path, filter))
	{
		watcher.Created += FileCreatedChangedDeleted;
		watcher.Changed += FileCreatedChangedDeleted;
		watcher.Deleted += FileCreatedChangedDeleted;
		watcher.Renamed += FileRenamed;
		watcher.Error   += FileError;

		watcher.IncludeSubdirectories = includeSubDirs;
		watcher.EnableRaisingEvents = true;

		Console.WriteLine ("Listening for events - press <enter> to end");
		Console.ReadLine();
	}
	// Disposing the FileSystemWatcher stops further events from firing.
}

void FileCreatedChangedDeleted (object o, FileSystemEventArgs e)
	=> Console.WriteLine ("File {0} has been {1}", e.FullPath, e.ChangeType);

void FileRenamed (object o, RenamedEventArgs e)
	=> Console.WriteLine ("Renamed: {0}->{1}", e.OldFullPath, e.FullPath);

void FileError (object o, ErrorEventArgs e)
	=> Console.WriteLine ("Error: " + e.GetException().Message);

string GetTestDirectory() =>
	RuntimeInformation.IsOSPlatform (OSPlatform.Windows)
		? @"C:\Temp"
		: "/tmp";